@@ -1,14 +1,23 @@
-//
-// C++ Interface: resultview
-//
-// Description:
-//
-//
-// Author: Paulo Moura Guedes <moura@kdewebdev.org>, (C) 2004
-//
-// Copyright: See COPYING file that comes with this distribution
-//
-//
+/***************************************************************************
+ *   Copyright (C) 2004 by Paulo Moura Guedes                              *
+ *   moura@kdewebdev.org                                                        *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
+ ***************************************************************************/
+
 #ifndef RESULTVIEW_H
 #define RESULTVIEW_H
 
@@ -28,6 +37,12 @@ class CellToolTip;
 class ResultView
 {
 public:
+    
+    static const QString URL_LABEL;
+    static const QString STATUS_LABEL;
+    static const QString MARKUP_LABEL;
+    static const QString LINK_LABEL_LABEL;
+    
     enum Status {
         none = 0,
         good,
@@ -36,9 +51,7 @@ public:
         undetermined // timeouts and refs
     };
 
-    ResultView(int column_index_status = 2,
-               int column_index_label = 3,
-               int column_index_URL = 1);
+    ResultView();
     virtual ~ResultView();
 
     //virtual void insertResult(LinkStatus const* linkstatus) = 0;
@@ -50,6 +63,13 @@ public:
     virtual void setColumns(QStringList const& columns);
     static bool displayableWithStatus(LinkStatus const* ls, Status const& status);
     
+    int numberOfColumns() const { return number_of_columns_; }
+    
+    int urlColumnIndex() const {return col_url_; }
+    int statusColumnIndex() const {return col_status_; }
+    int markupColumnIndex() const {return col_markup_; }
+    int labelColumnIndex() const {return col_label_; }
+
 protected:
     //virtual bool textFitsInCell(int row, int col) const = 0;
     virtual bool isEmpty() const = 0;
@@ -69,12 +89,16 @@ protected slots:
 
 protected:
     QStringList columns_;
-    uint col_status_;
-    uint col_label_;
-    uint col_url_;
+    int col_status_;
+    int col_label_;
+    int col_url_;
+    int col_markup_; // optional
     QPopupMenu context_table_menu_;
     QPopupMenu* sub_menu_;
     CellToolTip* cell_tip_;
+
+private:
+    int number_of_columns_;
 };
 
 
