@@ -872,7 +872,7 @@ void FormWindow::handleMouseRelease(QMouseEvent * e, QWidget * w)
                       "must first be broken.\n"
                       "Break the layout or cancel the operation?").
                   arg(wa->name()).arg(wa->name()), i18n("Inserting Widget"),
-                  i18n("&Break Layout"), i18n("&Cancel")) == KMessageBox::No)
+                  i18n("&Break Layout"), KStdGuiItem::cancel()) == KMessageBox::No)
             goto make_move_command; // cancel
           breakLayout(wa);
         }
@@ -962,7 +962,7 @@ void FormWindow::handleMouseRelease(QMouseEvent * e, QWidget * w)
                     "Break the layout or cancel the operation?").
                 arg(insertParent->name()).
                 arg(insertParent->name()), i18n("Inserting Widget"),
-                i18n("&Break Layout"), i18n("&Cancel")) == KMessageBox::Yes)
+                i18n("&Break Layout"), KStdGuiItem::cancel()) == KMessageBox::Yes)
         {
           breakLayout(insertParent);
         } else
@@ -1514,6 +1514,12 @@ void FormWindow::checkPreviewGeometry(QRect & r)
 
 void FormWindow::focusInEvent(QFocusEvent *)
 {
+  if (mContainer)
+  {
+    QVariant prop = mContainer->property("useInternalParser");
+    KommanderWidget::useInternalParser = prop.toBool();
+    
+  }
 }
 
 void FormWindow::focusOutEvent(QFocusEvent *)
@@ -1839,7 +1845,7 @@ void FormWindow::checkAccels()
       ok = false;
       if (KMessageBox::questionYesNo(mainWindow(),
               i18n("Accelerator '%1' is used %2 times.").arg(it.key().upper()).arg((*it).count()),
-              i18n("Check Accelerators"), i18n("&Select"), i18n("&Cancel")) == KMessageBox::Yes)
+              i18n("Check Accelerators"), i18n("&Select"), KStdGuiItem::cancel()) == KMessageBox::Yes)
       {
         clearSelection(false);
         for (wid = (*it).first(); wid; wid = (*it).next())
@@ -2143,7 +2149,7 @@ void FormWindow::saveBackground()
 
 void FormWindow::restoreConnectionLine()
 {
-  if (!unclippedPainter)
+  if (!unclippedPainter || !buffer)
     return;
 
   int a =QABS(connectStartPos.x() - currentConnectPos.x());
