@@ -90,11 +90,14 @@
 #include <qpopupmenu.h>
 #include <qmenubar.h>
 #include <qdatetimeedit.h>
+#include <qtoolbox.h>
 
 #include <stdlib.h>
 #include <kglobal.h>
 #include <klocale.h>
 
+#include "kmdrmainwindow.h"
+
 QPtrList<KommanderPlugin> widgetPlugins;
 
 QMap<QWidget*, QString> *qwf_functions = 0;
@@ -141,8 +144,12 @@ QWidget *KommanderFactory::create( QIODevice *dev, QObject *connector, QWidget *
     QDomDocument doc;
     QString errMsg;
     int errLine;
-    if ( !doc.setContent( dev, &errMsg, &errLine ) ) {
-	qDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
+    QTextStream stream(dev);
+    QString content = stream.read();
+    if (content.startsWith("#!"))
+      content = content.mid(content.find('\n'));
+    if ( !doc.setContent( content ) ) {
+// 	qDebug( QString("Parse error: ") + errMsg + QString(" in line %d"), errLine );
 	return 0;
     }
 
@@ -401,9 +408,9 @@ QWidget *KommanderFactory::createWidget( const QString &literalClassName, QWidge
   {
     QMainWindow *mw = 0;
     if (!qwf_stays_on_top)
-      mw = new QMainWindow(parent, name);
+      mw = new KmdrMainWindow(parent, name);
     else
-      mw = new QMainWindow(parent, name, Qt::WType_TopLevel | Qt::WStyle_StaysOnTop);
+      mw = new KmdrMainWindow(parent, name, Qt::WType_TopLevel | Qt::WStyle_StaysOnTop);
     mw->setCentralWidget(new QWidget(mw, "qt_central_widget"));
     mw->centralWidget()->show();
     (void) mw->statusBar();
@@ -480,7 +487,7 @@ FeatureList KommanderFactory::featureList()
 	for( it = widgets.begin() ; it != widgets.end() ; ++it )
 	{
 	    QString wn = *it;
-	    features[wn] = KommanderWidgetInfo( p->group(wn), p->toolTip(wn), p->whatsThis(wn), p->isContainer(wn) );
+	    features[wn] = KommanderWidgetInfo( p->group(wn), p->toolTip(wn),p->iconSet(wn), p->whatsThis(wn), p->isContainer(wn) );
 	}
     }
     return features;
@@ -541,6 +548,8 @@ QWidget *KommanderFactory::createWidgetInternal( const QDomElement &e, QWidget *
 	    layout = 0;
 	}
     }
+    if (className == "Dialog")
+       w->setProperty( "useInternalParser", false );
 
     while ( !n.isNull() ) {
 	if ( n.tagName() == "spacer" ) {
@@ -590,7 +599,11 @@ QWidget *KommanderFactory::createWidgetInternal( const QDomElement &e, QWidget *
 	    if ( parent->inherits( "QTabWidget" ) ) {
 		if ( attrib == "title" )
 		    ( (QTabWidget*)parent )->insertTab( w, translate(v.toString()) );
-	    } else if ( parent->inherits( "QWizard" ) ) {
+	    } else
+        if ( parent->inherits( "QToolBox" ) ) {
+        if ( attrib == "label" )
+            ( (QToolBox*)parent )->addItem( w, translate(v.toString()) );
+        }else if ( parent->inherits( "QWizard" ) ) {
 		if ( attrib == "title" )
 		    ( (QWizard*)parent )->addPage( w, translate(v.toString()) );
 	    }
@@ -613,6 +626,8 @@ QLayout *KommanderFactory::createLayout( QWidget *widget, QLayout*  layout, Layo
 
     if ( !layout && widget && widget->inherits( "QTabWidget" ) )
 	widget = ((QTabWidget*)widget)->currentPage();
+    if ( !layout && widget && widget->inherits( "QToolBox" ) )
+    widget = ((QToolBox*)widget)->currentItem();
 
     if ( !layout && widget && widget->inherits( "QWizard" ) )
 	widget = ((QWizard*)widget)->currentPage();
