@@ -29,6 +29,7 @@
 
 #include "kommanderwidget.h"
 #include "specials.h"
+#include "specialinformation.h"
 #include "expression.h"
 #include "parser.h"
 
@@ -64,6 +65,7 @@ QString KommanderWidget::evalFunction(const QString& function, const QStringList
       return QString();
     case Kommander::debug:
       qDebug("%s", args[0].latin1());
+      fflush(stderr);
       return QString::null;
     case Kommander::echo:
       for (uint i=0; i<args.count(); i++)
@@ -258,7 +260,6 @@ QString KommanderWidget::evalArrayFunction(const QString& function, const QStrin
     parser.setArray(array, args[1], args[2]);
   else if (fname == Array::fromString)
   {
-    parser.unsetArray(array);
     QStringList lines = QStringList::split("\n", args[1]);
     for (QStringList::Iterator it = lines.begin(); it != lines.end(); ++it)
     {
