@@ -136,6 +136,9 @@ QString KommanderWidget::evalAssociatedText(const QString& a_text)
   }
   /* Old macro-only parser is implemented below  */
 
+  bool parserType = KommanderWidget::useInternalParser;
+  KommanderWidget::useInternalParser = false; //shebang is used, switch to old parser
+
   QString evalText;
   int pos = 0, baseTextLength = a_text.length();
   while (pos < baseTextLength)
@@ -243,13 +246,16 @@ QString KommanderWidget::evalAssociatedText(const QString& a_text)
     }
   }
 
+  KommanderWidget::useInternalParser = parserType;
   return evalText;
 }
 
 
 QString KommanderWidget::DCOPQuery(const QStringList& a_query)
 {
-  QCString appId = a_query[0].latin1(), object = a_query[1].latin1();
+  QString app =  a_query[0];
+  app.remove("\"");
+  QCString appId = app.latin1(), object = a_query[1].latin1();
   
   // parse function arguments
   QString function = a_query[2], pTypes;
@@ -555,6 +561,13 @@ KommanderWidget* KommanderWidget::parseWidget(const QString& widgetName) const
     return dynamic_cast <KommanderWidget*>(parentDialog());
   QCString s = widgetName.lower() == "self" ? m_thisObject->name() : widgetName.latin1();
   QObject* childObj = parentDialog()->child(s);
+/*  if (!childObj)
+  {
+     Parser parser(internalParserData());
+     QString variableValue = parser.variable(widgetName).toString();
+     s = variableValue.lower() == "self" ? m_thisObject->name() : variableValue.latin1();
+     childObj = parentDialog()->child(s);  
+  }*/
   return dynamic_cast <KommanderWidget*>(childObj);
 }
 
@@ -702,7 +715,7 @@ bool KommanderWidget::isCommonFunction(int f)
   return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::children || f == DCOP::type;
 }
 
-ParserData* KommanderWidget::internalParserData()
+ParserData* KommanderWidget::internalParserData() const
 {
   return m_parserData;
 }
