@@ -26,14 +26,14 @@
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
+#include <kommander_export.h>
 
 class QWidget;
 class KProcess;
-
-class QShowEvent;
 class MyProcess;
 
-class ExecButton : public KPushButton, public KommanderWidget
+class QShowEvent;
+class KOMMANDER_EXPORT ExecButton : public KPushButton, public KommanderWidget
 {
   Q_OBJECT
 
