@@ -59,9 +59,11 @@ public slots:
 signals:
   void widgetOpened();
   void widgetTextChanged(const QString &);
+  void contextMenuRequested(int xpos, int ypos);
 protected:
   QObjectList m_childList;
   void showEvent(QShowEvent *e);
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
 };
 
