@@ -15,12 +15,14 @@
  ***************************************************************************/
 
 #include <kommanderplugin.h>
+#include <kiconloader.h>
 
 /* WIDGET INCLUDES */
 #include "buttongroup.h"
 #include "checkbox.h"
 #include "closebutton.h"
 #include "combobox.h"
+#include "datepicker.h"
 #include "dialog.h"
 #include "execbutton.h"
 #include "fileselector.h"
@@ -45,8 +47,11 @@
 #include "textedit.h"
 #include "timer.h"
 #include "treewidget.h"
+#include "toolbox.h"
 #include "wizard.h"
-
+#include "popupmenu.h"
+#include "fontdialog.h"
+#include "aboutdialog.h"
 
 class KomStdPlugin : public KommanderPlugin
 {
@@ -58,33 +63,38 @@ public:
 KomStdPlugin::KomStdPlugin()
 {
   const char *group = "Kommander";
-  addWidget("Label", group, "");
-  addWidget("PixmapLabel", group, "");
-  addWidget("LineEdit", group, "");
-  addWidget("Dialog", group, "");
-  addWidget("ExecButton", group, "");
-  addWidget("CloseButton", group, "");
-  addWidget("Konsole", group, "");
-  addWidget("TextEdit", group, "");
-  addWidget("RadioButton", group, "");
+  addWidget("Label", group, "", 0);
+  addWidget("PixmapLabel", group, "", 0);
+  addWidget("LineEdit", group, "", 0);
+  addWidget("Dialog", group, "", 0);
+  addWidget("ExecButton", group, "", 0);
+  addWidget("CloseButton", group, "", 0);
+  addWidget("Konsole", group, "", 0);
+  addWidget("TextEdit", group, "", 0);
+  addWidget("RadioButton", group, "", 0);
   // addWidget("", group, "");
-  addWidget("GroupBox", group, "");
-  addWidget("ButtonGroup", group, "");
-  addWidget("CheckBox", group, "");
-  addWidget("ComboBox", group, "");
-  addWidget("SpinBoxInt", group, "");
+  addWidget("GroupBox", group, "", 0);
+  addWidget("ButtonGroup", group, "", 0);
+  addWidget("CheckBox", group, "", 0);
+  addWidget("ComboBox", group, "", 0);
+  addWidget("SpinBoxInt", group, "", 0);
   // addWidget("Wizard", group, "");
-  addWidget("TabWidget", group, "");
+  addWidget("TabWidget", group, "", 0);
+  addWidget("ToolBox", group, "", new QIconSet(KGlobal::iconLoader()->loadIcon("toolbox", KIcon::NoGroup, KIcon::SizeMedium)), "", true);
   // addWidget("SubDialog", group, "");
-  addWidget("ListBox", group, "");
-  addWidget("Timer", group, "");
-  addWidget("ScriptObject", group, "");
-  addWidget("RichTextEditor", group, "");
-  addWidget("TreeWidget", group, "");
-  addWidget("StatusBar", group, "");
-  addWidget("TextBrowser", group, "");
-  addWidget("Slider", group, "");
-  addWidget("Table", group, "");
+  addWidget("ListBox", group, "", 0);
+  addWidget("Timer", group, "", 0);
+  addWidget("ScriptObject", group, "", 0);
+  addWidget("RichTextEditor", group, "", 0);
+  addWidget("TreeWidget", group, "", 0);
+  addWidget("StatusBar", group, "", 0);
+  addWidget("TextBrowser", group, "", 0);
+  addWidget("Slider", group, "", 0);
+  addWidget("Table", group, "", 0);
+  addWidget("DatePicker", group, "", 0);
+  addWidget("PopupMenu", group, "", new QIconSet(KGlobal::iconLoader()->loadIcon("contents", KIcon::NoGroup, KIcon::SizeMedium)));
+  addWidget("FontDialog", group, "", new QIconSet(KGlobal::iconLoader()->loadIcon("kfontcombo", KIcon::NoGroup, KIcon::SizeMedium)));
+  addWidget("AboutDialog", group, "", new QIconSet(KGlobal::iconLoader()->loadIcon("kommander", KIcon::NoGroup, KIcon::SizeMedium)));
 }
 
 QWidget *KomStdPlugin::create( const QString &key, QWidget *parent, const char *name )
@@ -112,11 +122,16 @@ QWidget *KomStdPlugin::create( const QString &key, QWidget *parent, const char *
   else if (key == "SubDialog") return new SubDialog(parent, name);
   else if (key == "Table") return new Table(parent, name);
   else if (key == "TabWidget") return new TabWidget(parent, name);
+  else if (key == "ToolBox") return new ToolBox(parent, name);
   else if (key == "TextBrowser") return new TextBrowser(parent, name);
   else if (key == "TextEdit") return new TextEdit(parent, name);
   else if (key == "Timer") return new Timer(parent, name);
   else if (key == "TreeWidget") return new TreeWidget(parent, name);
   else if (key == "Wizard") return new Wizard(parent, name);
+  else if (key == "DatePicker") return new DatePicker(parent, name);
+  else if (key == "PopupMenu") return new PopupMenu(parent, name);
+  else if (key == "FontDialog") return new FontDialog(parent, name);
+  else if (key == "AboutDialog") return new AboutDialog(parent, name);
   else return 0;
 }
 
