@@ -57,10 +57,14 @@ signals:
   void widgetOpened();
   void widgetTextChanged(const QString&);
   void contextMenuRequested(int xpos, int ypos);
+  void lostFocus();
+  void gotFocus();
 
 protected:
   void showEvent(QShowEvent* e);
   void contextMenuEvent( QContextMenuEvent * e );
+  void focusOutEvent( QFocusEvent* e);
+  void focusInEvent( QFocusEvent* e);
 };
 
 #endif
