@@ -3,6 +3,8 @@
                              -------------------
     copyright            : (C) 2002-2003 Marc Britton <consume@optusnet.com.au>
                            (C) 2004      Michal Rudolf <mrudolf@kdewebdev.org>
+                           (C) 2008      Andras Mantia <amantia@kdewebdev.org>
+                           (C) 2008      Eric Laffoon  <eric@kdewebdev.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,6 +20,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <klistview.h>
 
 /* QT INCLUDES */
 #include <qstring.h>
@@ -29,7 +32,24 @@
 /* OTHER INCLUDES */
 #include <specials.h>
 #include "treewidget.h"
+#include "kommanderplugin.h"
+#include "specials.h"
 
+#define TW_FUNCTION 275
+#define addColumnTree TW_FUNCTION+1
+#define setAltBackground TW_FUNCTION+2
+#define setColAlignment TW_FUNCTION+3
+//#define colCount TW_FUNCTION+3
+#define colCaption TW_FUNCTION+4
+#define setColWidth TW_FUNCTION+5
+#define setSortCol TW_FUNCTION+6
+#define TW_LAST_FUNCTION setSortCol
+
+enum Functions {
+  FirstFunction = 189,
+  SelectedIndexes,
+  LastFunction
+};
 
 TreeWidget::TreeWidget(QWidget *a_parent, const char *a_name)
   : KListView(a_parent, a_name), KommanderWidget(this)
@@ -39,6 +59,15 @@ TreeWidget::TreeWidget(QWidget *a_parent, const char *a_name)
   setStates(states);
   setDisplayStates(states);
   setPathSeparator("/");
+  KommanderPlugin::setDefaultGroup(Group::DCOP);
+  KommanderPlugin::registerFunction(SelectedIndexes, "selectedIndexes(QString widget)",  "", 1);
+  KommanderPlugin::registerFunction(addColumnTree, "addColumn(QString widget, const QString & label, int width = -1 )", i18n("Add column at end with column header"), 2, 3);
+  KommanderPlugin::registerFunction(setSortCol, "setSortColumn(QString widget, int column, bool ascending=true)", i18n("Set sorting for a column"), 2, 3);
+  //KommanderPlugin::registerFunction(setAltBackground, "setAltBackground(QString widget, const QColor & c)",  i18n("Alternate colors in list view"), 2);
+//  KommanderPlugin::registerFunction(colCount, "colCount(QString widget)", i18n("Get the column count"), 1);
+  KommanderPlugin::registerFunction(colCaption, "columnCaption(QString widget, int column)", i18n("Get the column caption for column index"), 2);
+  KommanderPlugin::registerFunction(setColWidth, "setColWidth(QString widget, int column, int width)", i18n("Set the pixel width for column index - use 0 to hide"), 3);
+  KommanderPlugin::registerFunction(setColAlignment, "setColumnAlignment(QString widget, int column, QString Alignment)", i18n("Set to <i>left</i>, <i>right</i> or <i>center</i>, case insensitive "), 3);
 }
 
 TreeWidget::~TreeWidget()
@@ -170,6 +199,8 @@ QString TreeWidget::itemPath(QListViewItem* item) const
   if (!item)
     return QString();
   item = item->parent();
+  if (!item)
+    return QString();
   QStringList path;
   while (item)
   {
@@ -233,12 +264,29 @@ void TreeWidget::showEvent(QShowEvent* e)
     emit widgetOpened();
 }
 
+void TreeWidget::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
+void TreeWidget::setColAlign(int column, const QString& align)
+{
+  if (align.lower() == "left")
+    setColumnAlignment (column, Qt::AlignLeft);
+  else if (align.lower() == "right")
+    setColumnAlignment (column, Qt::AlignRight);
+  else if (align.lower() == "center")
+    setColumnAlignment (column, Qt::AlignCenter);
+}
+
 bool TreeWidget::isFunctionSupported(int f)
 {
   return f == DCOP::insertItem || f == DCOP::text || f == DCOP::setText || f == DCOP::insertItems ||
     f == DCOP::selection || f == DCOP::setSelection || f == DCOP::clear || f == DCOP::removeItem || 
     f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::findItem || f == DCOP::item || 
-      f == DCOP::itemPath || f == DCOP::itemDepth || f == DCOP::setPixmap || f == DCOP::setColumnCaption;
+      f == DCOP::itemPath || f == DCOP::itemDepth || f == DCOP::setPixmap || f == DCOP::setColumnCaption || f == DCOP::removeColumn || f == DCOP::columnCount || f == DCOP::geometry || f == DCOP::hasFocus  || (f > FirstFunction && f < LastFunction) || (f >= TW_FUNCTION && f <= TW_LAST_FUNCTION);
 }
 
 QString TreeWidget::handleDCOP(int function, const QStringList& args)
@@ -259,8 +307,38 @@ QString TreeWidget::handleDCOP(int function, const QStringList& args)
         addItemFromString(*it);
       break;
     }
+    case SelectedIndexes:
+    {
+      QString selection = "";
+      QListViewItemIterator it(this);
+      while (it.current()) 
+      {
+        if (it.current()->isSelected())
+        {        
+          selection.append(QString("%1\n").arg(itemToIndex(it.current())));
+        }
+        ++it;
+      }
+      if (!selection.isEmpty())
+        selection = selection.left(selection.length() - 1);
+      return selection;
+      break;
+    }
     case DCOP::selection:
-      return itemText(currentItem());
+    {
+      QString selection = "";
+      QListViewItemIterator it(this);
+      while (it.current()) 
+      {
+        if (it.current()->isSelected())
+            selection.append(itemText(it.current()) + "\n");
+        ++it;
+      }
+      if (!selection.isEmpty())
+        selection = selection.left(selection.length() - 1);
+      return selection;
+      break;
+    }
     case DCOP::setSelection:
       if (selectionModeExt() == Single || selectionModeExt() == NoSelection)
         setCurrentItem(findItem(args[0], 0));
@@ -272,7 +350,10 @@ QString TreeWidget::handleDCOP(int function, const QStringList& args)
         {
           QListViewItem* item = findItem(*it, 0);
           if (item)
+          {
             item->setSelected(true);
+            ensureItemVisible(item);
+          }
         }
       }
       break;
@@ -286,15 +367,31 @@ QString TreeWidget::handleDCOP(int function, const QStringList& args)
       break;
     case DCOP::currentItem:
       return QString::number(itemToIndex(currentItem()));
+      break;
     case DCOP::setCurrentItem:
       setCurrentItem(indexToItem(args[0].toInt()));
       break;
     case DCOP::findItem:
-      return QString::number(itemToIndex(findItem(args[0], 0)));
+      if (!args[1])
+        return QString::number(itemToIndex(findItem(args[0], 0)));
+      else
+      {
+        if (args[2].toUInt() && args[3].toUInt())
+          return QString::number(itemToIndex(findItem(args[0], args[1].toInt())));
+        else if (args[2].toUInt())
+          return QString::number(itemToIndex(findItem(args[0], args[1].toInt(), Qt::CaseSensitive | Qt::Contains)));
+        else if (args[3].toUInt())
+          return QString::number(itemToIndex(findItem(args[0], args[1].toInt(), Qt::ExactMatch)));
+        else
+          return QString::number(itemToIndex(findItem(args[0], args[1].toInt(), Qt::Contains)));
+      }
+      break;
     case DCOP::item:
       return itemText(indexToItem(args[0].toInt()));
+      break;
     case DCOP::itemPath:
       return itemPath(indexToItem(args[0].toInt()));
+      break;
     case DCOP::itemDepth:
     {
       QListViewItem* item = indexToItem(args[0].toInt());
@@ -315,7 +412,51 @@ QString TreeWidget::handleDCOP(int function, const QStringList& args)
       break;
     }
     case DCOP::setColumnCaption:
-      setColumnText(args[0].toInt(), args[1]);
+      if (columns() >= args[0].toInt())
+        setColumnText(args[0].toInt(), args[1]);
+      break;
+    case addColumnTree:
+      return QString::number(KListView::addColumn(args[0], args[1].toInt()));
+      break;
+    case setSortCol:
+      KListView::setSorting(args[0].toInt(), args[1].toInt());
+      break;
+    case DCOP::columnCount:
+      return QString::number(QListView::columns() );
+      break;
+    case colCaption:
+       return QListView::columnText(args[0].toInt()) ;
+      break;
+    case setColWidth:
+      QListView::setColumnWidth(args[0].toInt(), args[1].toInt());
+      break;
+    case setColAlignment:
+      setColAlign(args[0].toInt(), args[1]);
+      break;
+    case setAltBackground:
+      KListView::setAlternateBackground(QColor(args[0]));
+      break;
+    case DCOP::removeColumn:
+    {
+      if (!args[1].toInt())
+        removeColumn(args[0].toInt());
+      else
+      {
+        int column = args[0].toInt();
+        int lines = args[1].toInt();
+        for (int i = 0; i < lines; i++)
+          removeColumn(column);
+      }
+      break;
+    }  
+    case DCOP::geometry:
+    {
+      QString geo = QString::number(this->x())+" "+QString::number(this->y())+" "+QString::number(this->width())+" "+QString::number(this->height());
+      return geo;
+      break;
+    }
+    case DCOP::hasFocus:
+      return QString::number(this->hasFocus());
       break;
     default:
       return KommanderWidget::handleDCOP(function, args);
