@@ -46,7 +46,8 @@ Wizard::Wizard(QWidget *a_parent, const char *a_name, bool a_modal, int a_flags)
 
 Wizard::~Wizard()
 {
-  destroy();
+  if (!inEditor)
+    destroy();
 }
 
 QString Wizard::currentState() const
@@ -169,6 +170,13 @@ void Wizard::showEvent(QShowEvent *e)
   emit widgetOpened();
 }
 
+void Wizard::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 QString Wizard::handleDCOP(int function, const QStringList& args)
 {
   switch (function) {
