@@ -62,6 +62,7 @@
 #include "xsldbgoutputview.h"
 #include "xsldbgconfigimpl.h"
 #include <kdebug.h>
+#include "xsldbgdebugger.h"
 
 typedef KParts::GenericFactory<KXsldbgPart> KXsldbgPartFactory;
 K_EXPORT_COMPONENT_FACTORY( libkxsldbgpart, KXsldbgPartFactory )
@@ -95,6 +96,7 @@ KXsldbgPart::KXsldbgPart( QWidget *parentWidget, const char * /*widgetName*/,
 
     QSplitter *splitter = new QSplitter(QSplitter::Vertical, frame);
     mainView = new QWidgetStack(splitter);
+    mainView->setMinimumHeight(400); //## TODO don't use a magic number 
     outputview = new XsldbgOutputView(splitter);
     setWidget(frame);
     docDictionary.setAutoDelete(true);
@@ -648,15 +650,26 @@ KXsldbgPart::lineNoChanged(QString fileName, int lineNumber, bool breakpoint)
 
   openURL(fileName);
 
+  QXsldbgDoc *docPtr;
+  QDictIterator<QXsldbgDoc> it(docDictionary);
+  while (it.current()){
+      docPtr = it.current();
+      // cause all Execution and BreakpointReached marks to be cleared
+      docPtr->clearMarks(false);
+      ++it;
+  }
  /* Did we stop at a breakpoint if so move the marker */
-  if (breakpoint && currentDoc) {
-      currentDoc->selectBreakPoint(lineNumber);
+  if (currentDoc) {
+      currentDoc->selectBreakPoint(lineNumber -1, breakpoint);
       QByteArray params;
       QDataStream stream(params, IO_WriteOnly);
       stream << currentFileName << lineNumber;
       emitDCOPSignal("debuggerPositionChanged(QString,int)", params);
+  }else {
+    qWarning("Unable to retrieve document from internal cache");
   }
 
+
   /* Move cursor and update status bar */
   if (currentDoc && currentDoc->kateView()){
       KTextEditor::ViewCursorInterface *cursorIf = KTextEditor::viewCursorInterface(currentDoc->kateView());   
@@ -801,12 +814,9 @@ void  KXsldbgPart::breakpointItem(QString fileName, int lineNumber ,
     /* Go through all documents and remove all breakpoints */
     QDictIterator<QXsldbgDoc> it(docDictionary);
     QXsldbgDoc *docPtr;
-    KTextEditor::MarkInterface *markIf = 0L;
     while (it.current()){
       docPtr = it.current();
-      markIf = KTextEditor::markInterface(docPtr->kateDoc());   
-      if (markIf)
-	   markIf->clearMarks();
+      docPtr->clearMarks(true);
      ++it;
     }
   }else{
@@ -820,10 +830,16 @@ void  KXsldbgPart::breakpointItem(QString fileName, int lineNumber ,
 	fetchURL(fileName);
     }
 */
+    fileName =  XsldbgDebugger::fixLocalPaths(fileName);
+    KURL temp(fileName);
+    fileName = temp.prettyURL();
     fetchURL(fileName);
     QXsldbgDoc *docPtr = docDictionary[fileName] ;
-   if (docPtr)
-	docPtr->enableBreakPoint(--lineNumber, enabled);
+   if (docPtr){
+        docPtr->addBreakPoint(lineNumber - 1, enabled);
+   }else {
+       qWarning("Unable to get doc %s from docDictionary", fileName.local8Bit().data());
+   }
   }
 }
 
