@@ -523,7 +523,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
 
                     /* quickly find a template */
                     /* skip any white spaces */
-                    while (IS_BLANK(arg[offset]))
+                    while (_IS_BLANK(arg[offset]))
                         offset++;
 
                     templateNode =
@@ -1060,6 +1060,9 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
     xmlDocPtr tempDoc = NULL;
     xmlNodePtr tempNode = NULL;
     rootCopy = root;
+    static const xmlChar *lastTemplate = NULL;
+    xmlBufferPtr buffer = xmlBufferCreate();
+    static char mybuff[6] = " 0\n\x0";
 
     if (ctxt && templ && root && !xsldbgReachedFirstTemplate)
 	xsldbgReachedFirstTemplate = true;
@@ -1100,10 +1103,31 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
 	  /* we only want messages if we are not
 	    in the process of completing the next command */
 	  if (terminalIO == NULL) {
-            if (root->match)
+
+            if (root->match){
                 xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp)));
-            else
+		if (lastTemplate != root->match && buffer){
+		    xmlBufferCCat(buffer, "\nreached matched template:");
+		    xmlBufferCat(buffer, root->match); 
+		    xmlBufferCCat(buffer, mybuff);
+		    xsltCopyTextString(ctxt, ctxt->insert,xmlBufferContent(buffer),0);
+		    mybuff[1]++;
+		    lastTemplate = root->match;
+		}
+            }else{
                 xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
+		if (lastTemplate != root->name && buffer){
+		    xmlBufferCCat(buffer, "\nreached named template:");
+		    xmlBufferCat(buffer,root->match); 
+		    xmlBufferCCat(buffer,mybuff);
+		    xsltCopyTextString(ctxt, ctxt->insert,xmlBufferContent(buffer),0);
+		    mybuff[1]++;
+		    lastTemplate = root->name;
+		}
+		
+	    }
+	    if (buffer)
+	       xmlBufferFree(buffer);
 	  } else {
             if ((xslDebugStatus == DEBUG_TRACE) ||
                 (xslDebugStatus == DEBUG_WALK)) {
