@@ -59,7 +59,6 @@ helpTop(const xmlChar * args)
     
 
     char buff[500], helpParam[100];
-    const QString appDataDir = KGlobal::dirs()->findResourceDir("data", "xsldbg/xsldbghelp.xsl");
 
     const char *docsDirPath =
         (const char *) optionsGetStringOption(OPTIONS_DOCS_PATH);
@@ -78,15 +77,14 @@ helpTop(const xmlChar * args)
                  " --param helpErrorTxt:%c'%s'%c "
                  " --output %s "
                  " --cd %s "
-                 "%sxsldbg%cxsldbghelp.xsl %s%cxsldbghelp.xml",
+                 "xsldbghelp.xsl xsldbghelp.xml",
                  XSLDBG_BIN, helpParam,
                  QUOTECHAR, VERSION, QUOTECHAR,
                  QUOTECHAR, xsldbgVerTxt.utf8().data(), QUOTECHAR,
                  QUOTECHAR, helpDocVerTxt.utf8().data(), QUOTECHAR,
                  QUOTECHAR, helpErrorTxt.utf8().data(), QUOTECHAR,
                  filesTempFileName(0),
-		 docsDirPath,
-                 appDataDir.utf8().data(), PATHCHAR, docsDirPath, PATHCHAR);
+		 docsDirPath);
         if (xslDbgShellExecute((xmlChar *) buff, optionsGetIntOption(OPTIONS_VERBOSE)) == 0) {
             if (docsDirPath)
                 xsldbgGenericErrorFunc(i18n("Error: Unable to display help. Help files not found in %1 or xsldbg not found in path.\n").arg(docsDirPath)); /* FIXME: Comments not correct - the command is that invoked  */
