@@ -168,7 +168,11 @@ extern "C" {
     xmlDocPtr xsldbgLoadXmlTemporary(const xmlChar * path);
 
 
-void xsldbgGenericErrorFunc(void *ctx, const char *msg, ...);
+void xsldbgGenericErrorFunc(void *ctx, const char *msg, ...)
+#ifdef __GNUC__
+      __attribute__ ( ( format ( printf, 2, 3 ) ) )
+#endif
+;
 int xsldbgMain(int argc, char **argv);
 
 #ifdef __cplusplus
