@@ -25,10 +25,11 @@ Q_OBJECT
   ~QXsldbgDoc();
 
   void enableBreakPoint(uint lineNumber, bool state);
-  void addBreakPoint(uint lineNumber);
+  void addBreakPoint(uint lineNumber, bool enabled);
   void deleteBreakPoint(uint lineNumber);
-  void selectBreakPoint(uint lineNumberbool);
+  void selectBreakPoint(uint lineNumberbool, bool reachedBreakPoint);
   bool isSelected(uint lineNumberbool);
+  void clearMarks(bool allMarkTypes);
 
   KURL url() const;
   KTextEditor::Document *kateDoc() {return kDoc;};
