@@ -150,7 +150,7 @@ int XsldbgConfigImpl::getParamCount()
 void XsldbgConfigImpl::addParam(QString name, QString value)
 {
 	LibxsltParam *param;
-	if ((name.length() == 0) | (value.length() == 0))
+	if ((name.length() == 0) || (value.length() == 0))
 		return;
 
 	param = getParam(name);
@@ -366,7 +366,7 @@ void XsldbgConfigImpl::slotOutputFile(QString outputFile)
 
 void XsldbgConfigImpl::slotChooseSourceFile()
 {
-	KURL url = KFileDialog::getOpenURL(QString::null, "*.xsl; *.XSL; *.Xsl \n *.*", this,
+	KURL url = KFileDialog::getOpenURL(QString::null, "*.xsl; *.XSL; *.Xsl ; *.xslt; *.XSLT; *.Xslt \n *.*", this,
 		i18n("Choose XSL Source to Debug"));
 	QString fileName = url.prettyURL();
 
