@@ -26,6 +26,7 @@
 #include <libxsldbg/xsldbgevent.h>
 #include <libxsldbg/qtnotifier2.h>
 #include <libxsldbg/options.h>
+#include <libxsldbg/files.h>
 
 extern int xsldbgStop;
 
@@ -119,10 +120,10 @@ QString XsldbgDebugger::fixLocalPaths(QString & file)
 {
     QString result = file;
 
-    if ((file.left(5) == "file:") && (file.left(8) != "file:///")){
-	KURL url(file);
-	// libxml2 does not like file:/<localfilepath>
-	result = "file://" + url.encodedPathAndQuery();
+    if (file.left(6) == "file:/"){
+        xmlChar * tempResult = filesExpandName((xmlChar *)file.utf8().data());
+        result = QString::fromUtf8((char*)tempResult);
+        xmlFree(tempResult);
     }
 
     return result;
@@ -134,7 +135,7 @@ QString XsldbgDebugger::sourceFileName()
 	QString fileName;
 
 	if (optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME) != 0L)
-		fileName = KURL::decode_string((const char*)optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME));
+		fileName = QString::fromUtf8((const char*)optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME));
 
 	return fileName;
 }
@@ -144,7 +145,7 @@ QString XsldbgDebugger::dataFileName()
 	QString fileName;
 
 	if (optionsGetStringOption(OPTIONS_DATA_FILE_NAME) != 0L)
-		fileName = KURL::decode_string((const char*)optionsGetStringOption(OPTIONS_DATA_FILE_NAME));
+		fileName = QString::fromUtf8((const char*)optionsGetStringOption(OPTIONS_DATA_FILE_NAME));
 
 	return fileName;
 }
@@ -154,7 +155,7 @@ QString XsldbgDebugger::outputFileName()
 	QString fileName;
 
 	if (optionsGetStringOption(OPTIONS_OUTPUT_FILE_NAME) != 0L)
-		fileName = KURL::decode_string((const char*)optionsGetStringOption(OPTIONS_OUTPUT_FILE_NAME));
+		fileName = QString::fromUtf8((const char*)optionsGetStringOption(OPTIONS_OUTPUT_FILE_NAME));
 
 	return fileName;
 }
