@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #ifndef KNEWSTUFF_ENGINE_H
 #define KNEWSTUFF_ENGINE_H
@@ -26,10 +26,6 @@
 
 #include "entry.h"
 #include "provider.h"
-#if !KDE_IS_VERSION(3,3,2)
-# undef KDE_EXPORT
-# define KDE_EXPORT
-#endif
 
 namespace KIO { class Job; }
 
