@@ -130,6 +130,7 @@ void  ProjectUpload::initProjectInfo(const QString& defaultProfile)
         m_defaultProfile = defaultProfile;
       QDomNodeList profileList = m_profilesNode.toElement().elementsByTagName("profile");
       QDomElement e;
+      m_currentProfileElement = profileList.item(0).toElement();
       QString s;
       int defaultIdx = 0;
       for (uint i = 0; i < profileList.count(); i++)
@@ -756,8 +757,9 @@ void ProjectUpload::reject()
   if (uploadInProgress && !m_profilesOnly)
   {
     suspendUpload = true;
+    //TODO when message freeze if lift: i18n("Upload") -> i18n("Continue") or "Continue upload"
     if (KMessageBox::questionYesNo(this,i18n("Do you really want to abort the upload?"),
-                                   i18n("Abort Upload"), i18n("Abort"), KStdGuiItem::cancel()) == KMessageBox::No)
+                                   i18n("Abort Upload"), i18n("Abort the uploading", "Abort"), i18n("Upload")) == KMessageBox::No)
     {
       suspendUpload = false;
       emit uploadNext();
