@@ -163,8 +163,11 @@ bool ViewManager::removeView(QuantaView *view, bool force, bool createNew)
         break;
     }
     delete it;
-    if (noOfViews == 1 && view->document()->isUntitled() && !view->document()->isModified() && createNew)
+    if (noOfViews == 1 && view->document() && view->document()->isUntitled() && !view->document()->isModified() && createNew)
+    {
+      quantaApp->slotShowPreviewWidget(false);
       return true;
+    }
     bool mayRemove = view->mayRemove();
     if (mayRemove)
     {
@@ -251,6 +254,8 @@ void ViewManager::slotCloseOtherTabs()
      currentView = m_contextView;
    else
      currentView = quantaApp->activeWindow();
+   if (dynamic_cast<QuantaView*>(currentView) && !static_cast<QuantaView*>(currentView)->document())
+     ToolbarTabWidget::ref()->reparent(0, 0, QPoint(), false);
   KMdiIterator<KMdiChildView*> *it = quantaApp->createIterator();
   //save the children first to a list, as removing invalidates our iterator
   QValueList<KMdiChildView *> children;
