@@ -380,8 +380,6 @@ void TagAttributeTree::editorContentChanged()
     if (dynamic_cast<AttributeNameSpaceItem*>(item))
     {
       QString nameSpace = item->editorText();
-      if (!nameSpace.isEmpty() && m_node->tag->type == Tag::XmlTagEnd)
-        nameSpace.prepend('/');
       m_node->tag->write()->changeTagNamespace(m_node->tag, nameSpace);
     } else
     {
@@ -536,7 +534,8 @@ void EnhancedTagAttributeTree::deleteSubTree()
     return;
   Node *oldCurNode;
   NodeModifsSet *modifs;
-  int curLine, curCol, offset;
+  int curLine, curCol;
+  long offset;
   DOM::Node domNode;
   QValueList<int> loc;
 
@@ -588,7 +587,8 @@ void EnhancedTagAttributeTree::deleteNode()
 
   Node *oldCurNode, *oldCurNodeParent, *child;
   QTag *oldCurNodeParentQTag;
-  int curLine, curCol, offset;
+  int curLine, curCol;
+  long offset;
   DOM::Node domNode;
   QValueList<int> loc;
   NodeModifsSet *modifs;
